@@ -35,7 +35,7 @@ Allows client to connect and run arbitrary functions in core.py.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.16'
+__version__ = '0.17'
 
 
 import datetime
@@ -119,7 +119,7 @@ class Server(object):
     if( clean_time is None ):
       self.clean_time = self.core_die_time
     self.cred_cache_instance = credentials.CredCache(self.config_instance,
-                                   inf_renew_time, unit_test)
+                                   self.inf_renew_time, unit_test)
     self.unittest_timestamp = unittest_timestamp
     self.core_store = [] # {'user': user, 'last_used': last_used, 'instance': }
     self.get_credentials_wait = {} # {'user1': 3, 'user2': 4}
@@ -153,8 +153,8 @@ class Server(object):
         datetime.datetime.now().isoformat()))
     log_file_contents.append(exception_string.getvalue())
     log_file_contents.append('\n---------------------\n')
+    log_file_handle = open(self.log_file, 'a')
     try:
-      log_file_handle = open(self.log_file, 'a')
       log_file_handle.writelines(''.join(log_file_contents))
     finally:
       log_file_handle.close()
@@ -181,8 +181,8 @@ class Server(object):
     log_file_contents.append('TIMESTAMP: %s' % (
         datetime.datetime.now().isoformat()))
     log_file_contents.append('\n---------------------\n')
+    log_file_handle = open(self.log_file, 'a')
     try:
-      log_file_handle = open(self.log_file, 'a')
       log_file_handle.writelines(''.join(log_file_contents))
     finally:
       log_file_handle.close()
